@@ -1,8 +1,8 @@
 import unittest
 
 loader = unittest.TestLoader()
-start_dir = './'
+start_dir = "./"
 suite = loader.discover(start_dir)
 
 runner = unittest.TextTestRunner()
-runner.run(suite)
\ No newline at end of file
+runner.run(suite)
